@@ -1,7 +1,7 @@
 package Perinci::Sub::Complete;
 
-our $DATE = '2015-09-09'; # DATE
-our $VERSION = '0.82'; # VERSION
+our $DATE = '2015-12-05'; # DATE
+our $VERSION = '0.83'; # VERSION
 
 use 5.010001;
 use strict;
@@ -9,7 +9,7 @@ use warnings;
 use Log::Any::IfLOG '$log';
 
 use Complete::Util qw(hashify_answer complete_array_elem combine_answers);
-use Complete::Setting;
+use Complete::Common qw(:all);
 use Perinci::Sub::Util qw(gen_modified_sub);
 
 require Exporter;
@@ -85,16 +85,12 @@ _
             schema => [str => default => ''],
             req => 1,
         },
-        ci => {
-            schema => 'bool',
-        },
     },
 };
 sub complete_from_schema {
     my %args = @_;
     my $sch  = $args{schema}; # must be normalized
     my $word = $args{word} // "";
-    my $ci   = $args{ci} // $Complete::Setting::OPT_CI;
 
     my $fres;
     $log->tracef("[comp][periscomp] entering complete_from_schema, word=<%s>, schema=%s", $word, $sch);
@@ -126,7 +122,6 @@ sub complete_from_schema {
                         complete_from_schema(
                             schema=>Data::Sah::Normalize::normalize_schema($_),
                             word => $word,
-                            ci => $ci,
                         )
                     } @{ $cs->{of} }
                 );
@@ -237,7 +232,7 @@ sub complete_from_schema {
 
     goto RETURN_RES unless $words;
     $fres = hashify_answer(
-        complete_array_elem(array=>$words, word=>$word, ci=>$ci),
+        complete_array_elem(array=>$words, word=>$word),
         {static=>$static && $word eq '' ? 1:0},
     );
 
@@ -289,10 +284,6 @@ _
             summary => 'Word to be completed',
             schema => ['str*', default => ''],
         },
-        ci => {
-            summary => 'Whether to be case-insensitive',
-            schema => ['bool*'],
-        },
         args => {
             summary => 'Collected arguments so far, '.
                 'will be passed to completion routines',
@@ -333,7 +324,6 @@ sub complete_arg_val {
         $log->tracef("[comp][periscomp] arg is not supplied, declining");
         goto RETURN_RES;
     };
-    my $ci   = $args{ci} // $Complete::Setting::OPT_CI;
     my $word = $args{word} // '';
 
     # XXX reject if meta's v is not 1.1
@@ -393,13 +383,12 @@ sub complete_arg_val {
                 $log->tracef("[comp][periscomp] invoking arg completion routine");
                 $fres = $comp->(
                     %$extras,
-                    word=>$word, ci=>$ci, arg=>$arg, args=>$args{args});
+                    word=>$word, arg=>$arg, args=>$args{args});
                 return; # from eval
             } elsif (ref($comp) eq 'ARRAY') {
                 # this is deprecated but will be supported for some time
                 $log->tracef("[comp][periscomp] using array specified in arg completion routine: %s", $comp);
-                $fres = complete_array_elem(
-                    array=>$comp, word=>$word, ci=>$ci);
+                $fres = complete_array_elem(array=>$comp, word=>$word);
                 $static++;
                 return; # from eval
             }
@@ -410,7 +399,7 @@ sub complete_arg_val {
                 my $res = $args{riap_client}->request(
                     complete_arg_val => $args{riap_server_url},
                     {(uri=>$args{riap_uri}) x !!defined($args{riap_uri}),
-                     arg=>$arg, word=>$word, ci=>$ci},
+                     arg=>$arg, word=>$word},
                 );
                 if ($res->[0] != 200) {
                     $log->tracef("[comp][periscomp] Riap request failed (%s), declining", $res);
@@ -432,7 +421,7 @@ sub complete_arg_val {
 
         # XXX normalize schema if not normalized
 
-        $fres = complete_from_schema(schema=>$sch, word=>$word, ci=>$ci);
+        $fres = complete_from_schema(schema=>$sch, word=>$word);
     };
     $log->debug("[comp][periscomp] completion died: $@") if $@;
     unless ($fres) {
@@ -486,7 +475,6 @@ sub complete_arg_elem {
         $log->tracef("[comp][periscomp] index is not supplied, declining");
         goto RETURN_RES;
     };
-    my $ci   = $args{ci} // $Complete::Setting::OPT_CI;
     my $word = $args{word} // '';
 
     # XXX reject if meta's v is not 1.1
@@ -548,12 +536,11 @@ sub complete_arg_elem {
                 $fres = $elcomp->(
                     %$extras,
                     %$ourextras,
-                    word=>$word, ci=>$ci);
+                    word=>$word);
                 return; # from eval
             } elsif (ref($elcomp) eq 'ARRAY') {
                 $log->tracef("[comp][periscomp] using array specified in arg element completion routine: %s", $elcomp);
-                $fres = complete_array_elem(
-                    array=>$elcomp, word=>$word, ci=>$ci);
+                $fres = complete_array_elem(array=>$elcomp, word=>$word);
                 $static = $word eq '';
             }
 
@@ -564,7 +551,7 @@ sub complete_arg_elem {
                 my $res = $args{riap_client}->request(
                     complete_arg_elem => $args{riap_server_url},
                     {(uri=>$args{riap_uri}) x !!defined($args{riap_uri}),
-                     arg=>$arg, args=>$args{args}, word=>$word, ci=>$ci,
+                     arg=>$arg, args=>$args{args}, word=>$word,
                      index=>$index},
                 );
                 if ($res->[0] != 200) {
@@ -602,7 +589,7 @@ sub complete_arg_elem {
         # does not do it yet
         my $elsch = Data::Sah::Normalize::normalize_schema($cs->{of});
 
-        $fres = complete_from_schema(schema=>$elsch, word=>$word, ci=>$ci);
+        $fres = complete_from_schema(schema=>$elsch, word=>$word);
     };
     $log->debug("[comp][periscomp] completion died: $@") if $@;
     unless ($fres) {
@@ -779,7 +766,6 @@ sub complete_cli_arg {
         my $type  = $cargs{type};
         my $ospec = $cargs{ospec} // '';
         my $word  = $cargs{word};
-        my $ci    = $cargs{ci} // $Complete::Setting::OPT_CI;
 
         my $fres;
 
@@ -849,7 +835,7 @@ sub complete_cli_arg {
                         $codata->{schema});
                     $log->tracef("[comp][periscomp] completing with common option's schema");
                     $fres = complete_from_schema(
-                        schema => $nsch, word=>$word, ci=>$ci);
+                        schema => $nsch, word=>$word);
                     goto RETURN_RES;
                 }
                 goto RETURN_RES;
@@ -963,7 +949,7 @@ Perinci::Sub::Complete - Complete command-line argument using Rinci metadata
 
 =head1 VERSION
 
-This document describes version 0.82 of Perinci::Sub::Complete (from Perl distribution Perinci-Sub-Complete), released on 2015-09-09.
+This document describes version 0.83 of Perinci::Sub::Complete (from Perl distribution Perinci-Sub-Complete), released on 2015-12-05.
 
 =head1 SYNOPSIS
 
@@ -1009,6 +995,8 @@ C<Complete>) which is either a hash or an array. The simplest form of answer is
 just to return an array of strings. Completion routine can also return undef to
 express declination.
 
+This function is not exported by default, but exportable.
+
 Arguments ('*' denotes required arguments):
 
 =over 4
@@ -1021,10 +1009,6 @@ Argument name.
 
 Collected arguments so far, will be passed to completion routines.
 
-=item * B<ci> => I<bool>
-
-Whether to be case-insensitive.
-
 =item * B<extras> => I<hash>
 
 Add extra arguments to completion routine.
@@ -1110,6 +1094,8 @@ C<Complete>) which is either a hash or an array. The simplest form of answer is
 just to return an array of strings. Completion routine can also return undef to
 express declination.
 
+This function is not exported by default, but exportable.
+
 Arguments ('*' denotes required arguments):
 
 =over 4
@@ -1122,10 +1108,6 @@ Argument name.
 
 Collected arguments so far, will be passed to completion routines.
 
-=item * B<ci> => I<bool>
-
-Whether to be case-insensitive.
-
 =item * B<extras> => I<hash>
 
 Add extra arguments to completion routine.
@@ -1182,6 +1164,8 @@ specification from arguments list in Rinci function metadata and common options.
 Then, it will use C<Complete::Getopt::Long> to complete option names, option
 values, as well as arguments.
 
+This function is not exported by default, but exportable.
+
 Arguments ('*' denotes required arguments):
 
 =over 4
@@ -1304,12 +1288,12 @@ schema is C<< [str =E<gt> in =E<gt> [qw/new open resolved rejected/]] >>, then w
 complete from the C<in> clause. Or for something like C<< [int =E<gt> between =E<gt> [1,
 20]] >> we can complete using values from 1 to 20.
 
+This function is not exported by default, but exportable.
+
 Arguments ('*' denotes required arguments):
 
 =over 4
 
-=item * B<ci> => I<bool>
-
 =item * B<schema>* => I<any>
 
 Must be normalized.
@@ -1343,7 +1327,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Perinci-Su
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/perlancar/perl-Perinci-Sub-Complete>.
+Source repository is at L<https://github.com/sharyanto/perl-Perinci-Sub-Complete>.
 
 =head1 BUGS
 
